#!/bin/bash
# Macht aus der XML-Version der Herrnhuter Losungen von http://www.losungen.de
# Losungstexte fuer jeden Tag im Jahr fuer 4Bibeln.
# (c) Peter Handrich - http://www.l4a.org/
# Lizenz des Skriptes: GNU Public License 3 - http://www.gnu.org/copyleft/gpl.html
# Handhabung: Skript und Losungstext muessen im gleichen Verzeichnis stehen.
# Einfach Skript aufrufen und auf Aufforderung den Namen der Datei angeben,
# die den Losungstext enthaelt.

# Info zur Textangabe
echo " "
echo " **********************************************************************"
echo " * Mit Hilfe dieses Skriptes wandeln Sie die XML-Version der Herrn-   *"
echo " * huter Losungen in das Format von 4Bibeln um.                       *"
echo " * Quelle: hhtp://www.losungen.de                                     *"
echo " **********************************************************************"
echo " "
echo " Bitte geben Sie den Namen der Datei an, die die Losungen enthaelt:"
echo " "

# Aufnahme der Tastatureingabe
read datei

# Anlegen eines Arbeitsverzeichnisses
mkdir ~/Losungen

# Entfernen ueberfluessiger Leerzeichen und/oder Tabulatoren am Zeilenanfang
sed 's/^[ \t]*//' $datei > ~/Losungen/datei1

# Entfernen aller Zeilen mit dem Tag '<Sonntag />'
grep -e '<Sonntag />' -v ~/Losungen/datei1 > ~/Losungen/datei2

# Loeschen der beiden Titelzeilen
sed '1,2 d' ~/Losungen/datei2 > ~/Losungen/datei1

# Konvertierung ins Unix-Textformat
dos2unix ~/Losungen/datei1

# Zusammenfassen der Zeilen einer Losung zu einer einzigen Teile pro Datum
sed ':a;N;$!ba;s/\n/@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/<Losungen>/XXX/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/<\/Losungen>/YYY/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@XXX/\nXXX/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/XXX\@<Datum>//g' ~/Losungen/datei1 > ~/Losungen/datei2

# Ermitteln des Jahres
sed -n '1,1 p' ~/Losungen/datei2 > ~/Losungen/datei3
jahr=`cut -c 1-4 ~/Losungen/datei3`

# Anlegen eines Unterverzeichnisses fuer das von den Losungen vertretene Jahr
mkdir ~/Losungen/$jahr

# Anlegen einer Indexdatei zum spaeteren Abspeichern der einzelnen HTML-Dateien
awk -FT '{ print $1 }' ~/Losungen/datei2 > ~/Losungen/datei4

# Erstellen einer Sicherungskopie
cp $datei ~/Losungen/Losungen-$jahr.xml.sicherung

# Loeschen der Ursprungsdatei
rm $datei

# Umwandlung von Zahlen in Monatsnamen
sed 's/-01-/@Januar#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-02-/@Februar#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/-03-/@März#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-04-/@April#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/-05-/@Mai#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-06-/@Juni#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/-07-/@Juli#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-08-/@August#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/-09-/@September#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-10-/@Oktober#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/-11-/@November#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/-12-/@Dezember#@/g' ~/Losungen/datei1 > ~/Losungen/datei2

# Loeschen von Tags
sed 's/T00:00:00/@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/<\/Datum>@<Wtag>/@/g' ~/Losungen/datei1 > ~/Losungen/datei2

# Umwandlung von digital formatierten Zahlen in Ordnungszahlen
sed 's/@01@@/@1.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@02@@/@2.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@03@@/@3.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@04@@/@4.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@05@@/@5.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@06@@/@6.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@07@@/@7.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@08@@/@8.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@09@@/@9.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@10@@/@10.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@11@@/@11.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@12@@/@12.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@13@@/@13.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@14@@/@14.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@15@@/@15.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@16@@/@16.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@17@@/@17.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@18@@/@18.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@19@@/@19.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@20@@/@20.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@21@@/@21.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@22@@/@22.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@23@@/@23.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@24@@/@24.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@25@@/@25.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@26@@/@26.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@27@@/@27.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@28@@/@28.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@29@@/@29.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/@30@@/@30.#@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/@31@@/@31.#@/g' ~/Losungen/datei2 > ~/Losungen/datei1

# Loeschen von Tags
sed 's/<\/Wtag>@<Losungstext>/@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/<\/Wtag>@<Sonntag>/ \| /g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/<\/Sonntag>@<Losungstext>/@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/<\/Losungstext>@<Losungsvers>/@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/<\/Losungsvers>@<Lehrtext>/@/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/<\/Lehrtext>@<Lehrtextvers>/@/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/<\/Lehrtextvers>@YYY//g' ~/Losungen/datei1 > ~/Losungen/datei2

# Ersetzen von Buchnamen
sed 's/1.Mose/Genesis/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Mose/Exodus/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/3.Mose/Levitikus/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/4.Mose/Numeri/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/5.Mose/Deuteronomium/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/1.Samuel/IXYZSamuel/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/2.Samuel/IIXYZSamuel/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/1.Könige/IXYZKoenige/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/2.Könige/IIXYZKoenige/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/1.Chronik/IXYZChronik/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/2.Chronik/IIXYZChronik/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Psalm/Psalmen/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Sprüche/Sprueche/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Hesekiel/Ezechiel/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Matthäus/Matthaeus/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Römer/Roemer/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1.Korinther/IXYZKorinther/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Korinther/IIXYZKorinther/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1.Thessalonicher/IXYZThessalonicher/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Thessalonicher/IIXYZThessalonicher/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1.Timotheus/IXYZTimotheus/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Timotheus/IIXYZTimotheus/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1.Petrus/IXYZPetrus/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Petrus/IIXYZPetrus/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1.Johannes/IXYZJohannes/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2.Johannes/IIXYZJohannes/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/3.Johannes/IIIXYZJohannes/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Hebräer/Hebraeer/g' ~/Losungen/datei1 > ~/Losungen/datei2

# Ersetzen von Sonntagsnamen und Setzen von Links zum Lektionar

sed 's/1. Sonntag im Advent/<a href="..\/..\/lektionar.htmlZYX1advent" target="ost"><span style="font-size:140%">1. Sonntag im Advent<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2. Sonntag im Advent/<a href="..\/..\/lektionar.htmlZYX2advent" target="ost"><span style="font-size:140%">2. Sonntag im Advent<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/3. Sonntag im Advent/<a href="..\/..\/lektionar.htmlZYX3advent" target="ost"><span style="font-size:140%">3. Sonntag im Advent<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/4. Sonntag im Advent/<a href="..\/..\/lektionar.htmlZYX4advent" target="ost"><span style="font-size:140%">4. Sonntag im Advent<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1. Sonntag nach Weihnachten/<a href="..\/..\/lektionar.htmlZYX1nchristfest" target="ost"><span style="font-size:140%">1. Sonntag nach Weihnachten<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2. Sonntag nach Weihnachten/<a href="..\/..\/lektionar.htmlZYX2nchristfest" target="ost"><span style="font-size:140%">2. Sonntag nach Weihnachten<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/1. Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYX1nepiphanias" target="ost"><span style="font-size:140%">1. Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/2. Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYX2nepiphanias" target="ost"><span style="font-size:140%">2. Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/3. Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYX3nepiphanias" target="ost"><span style="font-size:140%">3. Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/4. Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYX4nepiphanias" target="ost"><span style="font-size:140%">4. Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/5. Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYX5nepiphanias" target="ost"><span style="font-size:140%">5. Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Letzter Sonntag nach Epiphanias/<a href="..\/..\/lektionar.htmlZYXlnepiphanias" target="ost"><span style="font-size:140%">Letzter Sonntag nach Kutenholz<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Epiphanias/<a href="..\/..\/lektionar.htmlZYXepiphanias" target="ost"><span style="font-size:140%">Epiphanias<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Septuagesimae/<a href="..\/..\/lektionar.htmlZYXseptuagesimae" target="ost"><span style="font-size:140%">Septuagesimae<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Sexagesimae/<a href="..\/..\/lektionar.htmlZYXsexagesimae" target="ost"><span style="font-size:140%">Sexagesimae<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Estomihi/<a href="..\/..\/lektionar.htmlZYXestomihi" target="ost"><span style="font-size:140%">Estomihi<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Invocavit/<a href="..\/..\/lektionar.htmlZYXinvokavit" target="ost"><span style="font-size:140%">Invokavit<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Reminiscere/<a href="..\/..\/lektionar.htmlZYXreminiszere" target="ost"><span style="font-size:140%">Reminiszere<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Oculi/<a href="..\/..\/lektionar.htmlZYXokuli" target="ost"><span style="font-size:140%">Okuli<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Laetare/<a href="..\/..\/lektionar.htmlZYXlaetare" target="ost"><span style="font-size:140%">Laetare<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Judica/<a href="..\/..\/lektionar.htmlZYXjudika" target="ost"><span style="font-size:140%">Judika<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Palmsonntag/<a href="..\/..\/lektionar.htmlZYXpalmsonntag" target="ost"><span style="font-size:140%">Palmsonntag<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Osterfest/<a href="..\/..\/lektionar.htmlZYXosternacht" target="ost"><span style="font-size:140%">Ostersonntag<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Quasimodogeniti/<a href="..\/..\/lektionar.htmlZYXquasimodogeniti" target="ost"><span style="font-size:140%">Quasimodogeniti<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Misericordias Domini/<a href="..\/..\/lektionar.htmlZYXmisericordiasdomini" target="ost"><span style="font-size:140%">Miserikordias Domini<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Jubilate/<a href="..\/..\/lektionar.htmlZYXjubilate" target="ost"><span style="font-size:140%">Jubilate<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Cantate/<a href="..\/..\/lektionar.htmlZYXkantate" target="ost"><span style="font-size:140%">Kantate<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Rogate/<a href="..\/..\/lektionar.htmlZYXrogate" target="ost"><span style="font-size:140%">Rogate<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Exaudi/<a href="..\/..\/lektionar.htmlZYXexaudi" target="ost"><span style="font-size:140%">Exaudi<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Pfingstfest/<a href="..\/..\/lektionar.htmlZYXpfingstsonntag" target="ost"><span style="font-size:140%">Pfingstsonntag<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Erntedankfest/<a href="..\/..\/lektionar.htmlZYXerntedank" target="ost"><span style="font-size:140%">Erntedankfest<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/1. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX1ntrinitatis" target="ost"><span style="font-size:140%">1. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/2. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX2ntrinitatis" target="ost"><span style="font-size:140%">2. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/3. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX3ntrinitatis" target="ost"><span style="font-size:140%">3. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/4. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX4ntrinitatis" target="ost"><span style="font-size:140%">4. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/5. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX5ntrinitatis" target="ost"><span style="font-size:140%">5. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/6. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX6ntrinitatis" target="ost"><span style="font-size:140%">6. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/7. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX7ntrinitatis" target="ost"><span style="font-size:140%">7. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/8. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX8ntrinitatis" target="ost"><span style="font-size:140%">8. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/9. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX9ntrinitatis" target="ost"><span style="font-size:140%">9. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/10. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX10ntrinitatis" target="ost"><span style="font-size:140%">10. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/11. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX11ntrinitatis" target="ost"><span style="font-size:140%">11. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/12. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX12ntrinitatis" target="ost"><span style="font-size:140%">12. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/13. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX13ntrinitatis" target="ost"><span style="font-size:140%">13. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/14. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX14ntrinitatis" target="ost"><span style="font-size:140%">14. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/15. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX15ntrinitatis" target="ost"><span style="font-size:140%">15. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/16. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX16ntrinitatis" target="ost"><span style="font-size:140%">16. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/17. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX17ntrinitatis" target="ost"><span style="font-size:140%">17. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/18. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX18ntrinitatis" target="ost"><span style="font-size:140%">18. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/19. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX19ntrinitatis" target="ost"><span style="font-size:140%">19. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/20. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX20ntrinitatis" target="ost"><span style="font-size:140%">20. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/21. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX21ntrinitatis" target="ost"><span style="font-size:140%">21. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/22. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX22ntrinitatis" target="ost"><span style="font-size:140%">22. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/23. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX23ntrinitatis" target="ost"><span style="font-size:140%">23. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/24. Sonntag nach Trinitatis/<a href="..\/..\/lektionar.htmlZYX24ntrinitatis" target="ost"><span style="font-size:140%">24. Sonntag nach Sadersdorf<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Trinitatis/<a href="..\/..\/lektionar.htmlZYXtrinitatis" target="ost"><span style="font-size:140%">Trinitatis<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Drittletzter Sonntag des Kirchenjahres/<a href="..\/..\/lektionar.htmlZYXdrittletzter" target="ost"><span style="font-size:140%">Drittletzter Sonntag des Kirchenjahres<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1
sed 's/Vorletzter Sonntag des Kirchenjahres/<a href="..\/..\/lektionar.htmlZYXvorletzter" target="ost"><span style="font-size:140%">Vorletzter Sonntag des Kirchenjahres<\/span><\/a>/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Letzter Sonntag des Kirchenjahres/<a href="..\/..\/lektionar.htmlZYXletzter" target="ost"><span style="font-size:140%">Letzter Sonntag des Kirchenjahres<\/span><\/a>/g' ~/Losungen/datei2 > ~/Losungen/datei1

# Korrektur seltsamer Sonntagsnamen
sed 's/Kutenholz/Epiphanias/g' ~/Losungen/datei1 > ~/Losungen/datei2
sed 's/Sadersdorf/Trinitatis/g' ~/Losungen/datei2 > ~/Losungen/datei1

# Ersetzen aller Leerzeichen durch #
sed 's/ /#/g' ~/Losungen/datei1 > ~/Losungen/datei2

# Umsortieren einiger Spalten
awk -F@ '{ print $6 "@" $8 "@" $1 "@" $2 "@" $3 "@" $4 "@" $5 "@" $7 "@" $6 "@" $8 }' ~/Losungen/datei2 > ~/Losungen/datei1

# Ersetzen des ersten Kommas durch einen :
sed 's/,/:/' ~/Losungen/datei1 > ~/Losungen/datei2

# Ersetzen des zweiten Kommas durch einen :
sed 's/,/:/' ~/Losungen/datei2 > ~/Losungen/datei1

# Ersetzen des ersten # durch +
sed 's/#/+/' ~/Losungen/datei1 > ~/Losungen/datei2

# Ersetzen des zweiten # durch +
sed 's/#/+/' ~/Losungen/datei2 > ~/Losungen/datei1

# Ruecksortieren der Spalten mit HTML-Tags
awk -F@ '{ print "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"> <html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"de\" lang=\"de\" dir=\"ltr\"> <head> <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /> <link rel=\"copyright\" href=\"http://www.gnu.org/copyleft/gpl.html\" /> <link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/style.css\" /> <title>4Bibeln: Losungen</title> </head> <body> <h1>4Bibeln: <i>Losungen</i></h1> <p><h4> Losungen der Herrnhuter Brüdergemeine</h4></p> <p><h3>" $5 $4 $3 " | " $6 "</h3></p> <li><b>" $7 "<br /> <a href=\"../../../cgi-bin/4bibeln?lookupMode=aufschlagen&lookup=" $1 "\" target=\"ost\">" $9 "</a></b></li><br /> <li><b>" $8  "<br /> <a href=\"../../../cgi-bin/4bibeln?lookupMode=aufschlagen&lookup=" $2 "\" target=\"ost\">" $10 "</a></b> </body> </html>" }' ~/Losungen/datei1 > ~/Losungen/datei2

# Ersetzen aller # durch Leerzeichen
sed 's/#/ /g' ~/Losungen/datei2 > ~/Losungen/datei1

# Korrektur zusammengesetzter Buchnamen
sed 's/XYZ/ /g' ~/Losungen/datei1 > ~/Losungen/datei2

# Korrektur von HTML-Ankern
sed 's/ZYX/#/g' ~/Losungen/datei2 > ~/Losungen/datei1

# Isolieren der jeweils ersten Zeile der Textdatei fuer die jeweilge Losungsdatei
until [ ! -s ~/Losungen/datei1 ]
    do
    head -1 ~/Losungen/datei1 > ~/Losungen/datei2
    head -1 ~/Losungen/datei4 > ~/Losungen/datei3
    monat=`cut -c 6-7 ~/Losungen/datei3`
    tag=`cut -c 9-10 ~/Losungen/datei3`
    mv ~/Losungen/datei2 ~/Losungen/$jahr/$monat$tag.html
    mv ~/Losungen/datei1 ~/Losungen/datei2
    mv ~/Losungen/datei4 ~/Losungen/datei3
    sed -n '2,$ p' ~/Losungen/datei2 > ~/Losungen/datei1
    sed -n '2,$ p' ~/Losungen/datei3 > ~/Losungen/datei4
    done

# Die ersten werden die letzten sein
cp ~/Losungen/$jahr/0101.html ~/Losungen/$jahr/1301.html

# Loeschen der Hilfsdateien
rm ~/Losungen/datei*

# Kopieren der Jahres- und Monatssprueche ins Losungsverzeichnis
cp ~/Losungen/oeab$jahr.html ~/Losungen/$jahr/oeab.html

# Verzeichniswechsel und Packen einer Datei zum Upload auf http://www.l4a.org
cd ~/Losungen/$jahr/
tar -jcvf ~/Losungen/los$jahr.tar.bz2 *

# Informationen am Schluss
echo " "
echo "Sie finden die Dateien Ihrer neuen Losungen in Ihrem"
echo "Heimatverzeichnis und dort im Unterverzeichnis Losungen"
echo "und dort wiederum im Unterverzeichnis mit der Jahreszahl"
echo "der von Ihnen bearbeiteten Losungen."
echo " "
echo "Um die neuen Losungen benutzen zu koennen, muessen Sie sie als"
echo "Superuser (root) mit Hilfe eines Dateimanagers oder des Kommandos"
echo "cp ~/Losungen/Jahreszahl/* /Pfad/zu/Webserverdateien/4bibeln/Jahreszahl/*"
echo "kopieren."
echo " "
echo "Sie sollten anschliessend das Verzeichnis Losungen in Ihrem Heimat-"
echo "verzeichnis löschen, um den benutzten Platz frei zu machen."
echo " "
echo "            ********** - Ende der Arbeiten - **********"
echo " "
